.tippy-popper[x-placement^=top] .tippy-tooltip.light-theme .tippy-arrow{border-top:7px solid #fff;border-right:7px solid transparent;border-left:7px solid transparent}.tippy-popper[x-placement^=bottom] .tippy-tooltip.light-theme .tippy-arrow{border-bottom:7px solid #fff;border-right:7px solid transparent;border-left:7px solid transparent}.tippy-popper[x-placement^=left] .tippy-tooltip.light-theme .tippy-arrow{border-left:7px solid #fff;border-top:7px solid transparent;border-bottom:7px solid transparent}.tippy-popper[x-placement^=right] .tippy-tooltip.light-theme .tippy-arrow{border-right:7px solid #fff;border-top:7px solid transparent;border-bottom:7px solid transparent}.tippy-tooltip.light-theme{color:#26323d;box-shadow:0 0 20px 4px rgba(154,161,177,.15),0 4px 80px -8px rgba(36,40,47,.25),0 4px 4px -2px rgba(91,94,105,.15);background-color:#fff}.tippy-tooltip.light-theme .tippy-backdrop{background-color:#fff}.tippy-tooltip.light-theme .tippy-roundarrow{fill:#fff}.tippy-tooltip.light-theme[data-animatefill]{background-color:transparent}.glossary-definition-popup{position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;text-align:left}.glossary-definition-popup .glossary-term{font-weight:bold;width:12rem;margin:1rem}.glossary-definition-popup .glossary-definition{margin:0 1rem}.glossaryAbcedaire,#content ul.glossaryAbcedaire{list-style:none;margin:0;margin-bottom:1em}.glossaryAbcedaire li,#content ul.glossaryAbcedaire li{display:inline;margin:0;margin-right:0.5em}.glossaryAbcedaire .selected,#content ul.glossaryAbcedaire .selected{font-weight:bold;font-size:150%;text-decoration:none}#glossary_search #search_text{display:inline-block;width:auto}.highlightedGlossaryTerm{border-bottom:2px dotted #000;background:#eef3f5;cursor:help;z-index:2}
