# -*- coding: utf-8 -*-
PROJECTNAME = "kitconcept.glossary"

# by default, all standard content types will be enabled
DEFAULT_ENABLED_CONTENT_TYPES = [
    "Collection",
    "Document",
    "File",
    "Image",
    "Link",
    "News Item",
]
